==> order-center-domain-3.0.0-CLOUD-DEV-20250409.072946-169-sources.jar: com/tydic/dyc/oc/model/cmporder/sub/UocCmpOrderItem.java <==
package com.tydic.dyc.oc.model.cmporder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocCmpOrderItemPo
 * 说明:比选明细表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocCmpOrderItem implements Serializable {
	private static final long serialVersionUID =  -2962530616411325212L;

	@DocField(value = "比选单明细id")
	private Long cmpOrderItemId;

	@DocField(value = "比选单id")
	private Long cmpOrderId;

	@DocField(value = "单品id	")
	private String skuId;

	@DocField(value = "商品id	")
	private String spuId;

	@DocField(value = "供应商id	")
	private String goodsSupplierId;

	@DocField(value = "所属供应商名称")
	private String goodsSupplierName;

	@DocField(value = "店铺id	")
	private String shopId;

	@DocField(value = "原商品购物车id(比选原商品必传)	")
	private String cartId;

	@DocField(value = "销售价")
	private String skuSalePrice;

	@DocField(value = "总价")
	private String totalSalePrice;

	@DocField(value = "销售单位")
	private String unitName;

	@DocField(value = "商品名称")
	private String skuName;

	@DocField(value = "数量")
	private String purchaseCount;

	@DocField(value = "规格")
	private String specification;

	@DocField(value = "图片地址	")
	private String imgUrl;

	@DocField(value = "是否暂无（是的传   暂无）	")
	private String nothing;

	@DocField(value = "排序（页面第几个）	")
	private Integer skuOrder;

	@DocField(value = "物料id")
	private String materialId;

	@DocField(value = "交货时间")
	private Date deliveryTime;

	@DocField(value = "品牌")
	private String brand;

	@DocField(value = "型号")
	private String model;

	@DocField(value = "销量")
	private BigDecimal saleCount;

	@DocField(value = "物料名称")
	private String materialName;

	@DocField(value = "上架时间")
	private Date shelvesTime;

	@DocField(value = "好评率")
	private BigDecimal positiveRate;

	@DocField(value = "售后服务政策")
	private String afsPolicy;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "比选单明细扩展")
	private List<UocCmpItemMap> uocCmpItemMapList;

	@DocField(value = "单品来源      1 自营单品   2 电商导入   3 协议生成")
	private Integer skuSource;

	/**
	 * 租户id
	 */
	private Long sysTenantId;
	private String sysTenantName;
}

==> order-center-domain-3.1.0-CLOUD-DEV-20230209.091019-21-sources.jar: com/tydic/dyc/oc/model/cmporder/sub/UocCmpOrderItem.java <==
package com.tydic.dyc.oc.model.cmporder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocCmpOrderItemPo
 * 说明:比选明细表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocCmpOrderItem implements Serializable {
	private static final long serialVersionUID =  -2962530616411325212L;

	@DocField(value = "比选单明细id")
	private Long cmpOrderItemId;

	@DocField(value = "比选单id")
	private Long cmpOrderId;

	@DocField(value = "单品id	")
	private String skuId;

	@DocField(value = "商品id	")
	private String spuId;

	@DocField(value = "供应商id	")
	private String goodsSupplierId;

	@DocField(value = "所属供应商名称")
	private String goodsSupplierName;

	@DocField(value = "店铺id	")
	private String shopId;

	@DocField(value = "原商品购物车id(比选原商品必传)	")
	private String cartId;

	@DocField(value = "销售价")
	private String skuSalePrice;

	@DocField(value = "总价")
	private String totalSalePrice;

	@DocField(value = "销售单位")
	private String unitName;

	@DocField(value = "商品名称")
	private String skuName;

	@DocField(value = "数量")
	private String purchaseCount;

	@DocField(value = "规格")
	private String specification;

	@DocField(value = "图片地址	")
	private String imgUrl;

	@DocField(value = "是否暂无（是的传   暂无）	")
	private String nothing;

	@DocField(value = "排序（页面第几个）	")
	private Integer skuOrder;

	@DocField(value = "物料id")
	private String materialId;

	@DocField(value = "交货时间")
	private Date deliveryTime;

	@DocField(value = "交货时间字符串")
	//部分电商返回是字符串，用于向前兼容date类型，数据库增加一个String类型的字段
	private String deliveryTimeStr;

	@DocField(value = "品牌")
	private String brand;

	@DocField(value = "型号")
	private String model;

	@DocField(value = "销量")
	private BigDecimal saleCount;

	@DocField(value = "物料名称")
	private String materialName;

	@DocField(value = "上架时间")
	private Date shelvesTime;

	@DocField(value = "好评率")
	private BigDecimal positiveRate;

	@DocField(value = "售后服务政策")
	private String afsPolicy;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "比选单明细扩展")
	private List<UocCmpItemMap> uocCmpItemMapList;

	@DocField(value = "单品来源      1 自营单品   2 电商导入   3 协议生成")
	private Integer skuSource;
}
